Changelog
=========

Version 0.1 [2020-09-10]
------------------------

First and last release of django-freeradius.
Development has moved to `openwisp-radius <https://github.com/openwisp/openwisp-radius>`_,
this repository is archived.
